====
tuul
====


.. image:: https://img.shields.io/pypi/v/tuul.svg
        :target: https://pypi.python.org/pypi/tuul



python toolbox


* Free software: MIT license


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
